<?php
/* $Id: bosnian-windows-1250.inc.php,v 2.69 2005/06/12 10:09:56 swix Exp $ */

/**
 *     Translated by:
 *     Samir Kobiljak <kobiljak@aon.at>
 *     http://www.kobiljak.com
 */

$charset = 'windows-1250';
$text_dir = 'ltr'; // ('ltr' for left to right, 'rtl' for right to left)
$left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
$right_font_family = 'arial, helvetica, geneva, sans-serif';
$number_thousands_separator = ',';
$number_decimal_separator = '.';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('bajta', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');

$day_of_week = array('Ned', 'Pon', 'Uto', 'Sri', 'et', 'Pet', 'Sub');
$month = array('jan', 'feb', 'mar', 'apr', 'maj', 'jun', 'jul', 'aug', 'sep', 'okt', 'nov', 'dec');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%d. %B %Y. u %H:%M';
$timespanfmt = '%s dana, %s sati, %s minuta i %s sekundi';

$strAPrimaryKey = 'Osnovni klju je upravo dodan %s';
$strAbortedClients = 'Prekinuto';
$strAbsolutePathToDocSqlDir = 'Unesite kompletnu putanju do direkcije docSQL na veb serveru';
$strAccessDenied = 'Ulaz nije dozvoljen';
$strAccessDeniedExplanation = 'phpMyAdmin je pokuao da se povee na MySQL server, ali je server odbio povezivanje. Provjerite naziv hosta, korisniko ime i lozinku u config.inc.php i uvjerite se da odgovaraju podacima koje ste dobili od administratora MySQL servera.';
$strAction = 'Akcija';
$strAddAutoIncrement = 'Dodaj AUTO_INCREMENT vrijednost';
$strAddDeleteColumn = 'Dodaj/obrii kolonu';
$strAddDeleteRow = 'Dodaj/obrii polje za kriterij';
$strAddDropDatabase = 'Dodaj DROP DATABASE';
$strAddIntoComments = 'Dodaj u komentare';
$strAddNewField = 'Dodaj novo polje';
$strAddPrivilegesOnDb = 'Dodaj privilegije na slijedeoj bazi';
$strAddPrivilegesOnTbl = 'Dodaj privilegije na slijedeoj tabeli';
$strAddSearchConditions = 'Dodaj uslove pretraivanja (dio "WHERE" upita):';
$strAddToIndex = 'Dodaj u klju &nbsp;%s&nbsp;kolona(e)';
$strAddUser = 'Dodaj novog korisnika';
$strAddUserMessage = 'Dodali ste novog korisnika.';
$strAddedColumnComment = 'Dodan je komentar koloni';
$strAddedColumnRelation = 'Dodana je relacija koloni';
$strAdministration = 'Administracija';
$strAffectedRows = 'Obuhvaeno redova:';
$strAfter = 'Poslije %s';
$strAfterInsertBack = 'Nazad na prethodnu stranu';
$strAfterInsertNewInsert = 'Dodaj jo jedan novi red';
$strAll = 'Sve';
$strAllTableSameWidth = 'prikaz svih tabela iste irine?';
$strAlterOrderBy = 'Promijeni redoslijed u tabeli';
$strAnIndex = 'Klju je upravo dodan %s';
$strAnalyzeTable = 'Analiziraj tabelu';
$strAnd = 'i';
$strAny = 'Bilo koji';
$strAnyHost = 'Bilo koji host';
$strAnyUser = 'Bilo koji korisnik';
$strArabic = 'Arapski';
$strArmenian = 'Jermenski';
$strAscending = 'Rastui';
$strAtBeginningOfTable = 'Na poetku tabele';
$strAtEndOfTable = 'Na kraju tabele';
$strAttr = 'Atributi';
$strAutodetect = 'automatski';
$strAutomaticLayout = 'Automatski raspored';

$strBack = 'Nazad';
$strBaltic = 'Baltiki';
$strBeginCut = 'POETAK REZ';
$strBeginRaw = 'POETAK SIROVO';
$strBinary = 'Binarni';
$strBinaryDoNotEdit = 'Binarni - ne mijenjaj';
$strBookmarkDeleted = 'Obiljeiva je upravo obrisan.';
$strBookmarkLabel = 'Naziv';
$strBookmarkQuery = 'Obiljeen SQL-upit';
$strBookmarkThis = 'Obiljei SQL-upit';
$strBookmarkView = 'Vidi samo';
$strBrowse = 'Pregled';
$strBrowseForeignValues = 'Pregledaj strane vrijednosti';
$strBulgarian = 'Bugarski';
$strBzError = 'phpMyAdmin nije mogao da kompresuje sadraj baze zbog neispravne BZ2 ekstenzije u ovoj verziji PHP-a. Preporuuje se da podesite <code>$cfg[\'BZipDump\']</code> direktivu u vaem phpMyAdmin konfiguracionom fajlu na <code>FALSE</code>. Ako elite da koristite mogunosti BZ2 kompresije, trebalo bi da preete na noviju verziju PHP-a. Vidite PHP izvetaj o grekama %s za detalje.';
$strBzip = '"bzip-ovano"';

$strCSVOptions = 'CSV opcije';
$strCannotLogin = 'Ne mogu da se prijavim na MySQL server';
$strCantLoad = 'ne mogu da uitam ekstenziju %s,<br />molim provjerite PHP konfiguraciju';
$strCantLoadRecodeIconv = 'Ne mogu da uitam iconv ili recode ekstenzije potrebne za konverziju skupova znakova, podesite PHP da dozvoli korienje ovih ekstenzija ili onemoguite konverziju skupova znakova u phpMyAdmin-u.';
$strCantRenameIdxToPrimary = 'Ne mogu da promenim klju u PRIMARY (primarni) !';
$strCantUseRecodeIconv = 'Ne mogu da koristim iconv ili libiconv ili recode_string funkcije iako ekstenzija prijavljuje da je uitana. Proverite vau PHP konfiguraciju.';
$strCardinality = 'Kardinalnost';
$strCarriage = 'Novi red (carriage return): \\r';
$strCaseInsensitive = 'Ne razlikuje mala i velika slova';
$strCaseSensitive = 'Razlikuje mala i velika slova';
$strCentralEuropean = 'Centralnoevropski';
$strChange = 'Promijeni';
$strChangeCopyMode = 'Napravi novog korisnika sa istim privilegijama i ...';
$strChangeCopyModeCopy = '... sauvaj stare.';
$strChangeCopyModeDeleteAndReload = ' ... obrii starog iz tabele korisnika i zatim ponovo uitaj privilegije.';
$strChangeCopyModeJustDelete = ' ... obrii stare iz tabela korisnika.';
$strChangeCopyModeRevoke = ' ... obustavi sve privilegije starog korisnika i zatim ga obrii.';
$strChangeCopyUser = 'Promeni informacije o prijavi / Kopiraj korisnika';
$strChangeDisplay = 'Izaberi polja za prikaz';
$strChangePassword = 'Promeni lozinku';
$strCharset = 'Karakter set';
$strCharsetOfFile = 'Karakter set datoteke:';
$strCharsets = 'Kodne strane';
$strCharsetsAndCollations = 'Karakter setovi i sortiranje';
$strCheckAll = 'Oznai sve';
$strCheckPrivs = 'Provjeri privilegije';
$strCheckPrivsLong = 'Provjeri privilegije za bazu &quot;%s&quot;.';
$strCheckTable = 'Provjeri tabelu';
$strChoosePage = 'Izaberite stranu koju menjate';
$strColComFeat = 'Prikazujem komentare kolone';
$strCollation = 'Sortiranje';
$strColumnNames = 'Imena kolona';
$strColumnPrivileges = 'Privilegije vezane za kolone';
$strCommand = 'Naredba';
$strComments = 'Komentari';
$strCompleteInserts = 'Kompletan INSERT (sa imenima polja)';
$strCompression = 'Kompresija';
$strConfigFileError = 'phpMyAdmin nije mogao da proita va konfiguracioni fajl!<br />Ovo se moe destiti ako PHP nae greku u procesiranju ili ne moe da pronae fajl.<br />Pozovite konfiguracioni fajl direktno koristei donji link u proitajte poruke o greci koje dobijate. U veini sluajeve negde nedostaje navodnik ili taka-zarez.<br />Ako dobijete praznu stranu, sve je u redu.';
$strConfigureTableCoord = 'Podesite koordinate za tabelu %s';
$strConnections = 'Konekcije';
$strCookiesRequired = 'Kolaii (Cookies) moraju u ovom sluaju biti aktivirani.';
$strCopyTable = 'Kopiraj tabelu u (baza<b>.</b>tabela):';
$strCopyTableOK = 'Tabela %s je kopirana u %s.';
$strCopyTableSameNames = 'Ne mogu da kopiram tabelu u samu sebe!';
$strCouldNotKill = 'phpMyAdmin nije mogao da prekine proces %s. Vjerovatno je ve zatvoren.';
$strCreate = 'Napravi';
$strCreateIndex = 'Napravi klju na&nbsp;%s&nbsp;kolona';
$strCreateIndexTopic = 'Napravi novi klju';
$strCreateNewDatabase = 'Napravi novu bazu podataka';
$strCreateNewTable = 'Napravi novu tabelu u bazi %s';
$strCreatePage = 'Napravi novu stranu';
$strCreatePdfFeat = 'Pravljenje PDF-ova';
$strCriteria = 'Kriterijum';
$strCroatian = 'Hrvatski';
$strCyrillic = 'irilini';
$strCzech = 'eki';

$strDBComment = 'Komentar baze:';
$strDBGContext = 'Kontekst';
$strDBGContextID = 'Kontekst ID';
$strDBGHits = 'Pogodaka';
$strDBGLine = 'Linija';
$strDBGMaxTimeMs = 'Max vrijeme, ms';
$strDBGMinTimeMs = 'Min vrijeme, ms';
$strDBGModule = 'Modul';
$strDBGTimePerHitMs = 'Vrijeme/pogodak, ms';
$strDBGTotalTimeMs = 'Ukupno vrijeme, ms';
$strDanish = 'Danski';
$strData = 'Podaci';
$strDataDict = 'Renik podataka';
$strDataOnly = 'Samo podaci';
$strDatabase = 'Baza podataka';
$strDatabaseExportOptions = 'Opcije za izvoz baze';
$strDatabaseHasBeenDropped = 'Baza %s je odbaena.';
$strDatabaseNoTable = 'Baza ne sadri tabele!';
$strDatabases = 'Baze';
$strDatabasesDropped = '%s baza je uspjeno odbaena.';
$strDatabasesStats = 'Statistika baze';
$strDatabasesStatsDisable = 'Iskljui statistike';
$strDatabasesStatsEnable = 'Ukljui statistike';
$strDatabasesStatsHeavyTraffic = 'Napomena: ukljuivanje statistika moe prouzrokovati veliki protok podataka izmeu web i MySQL servera.';
$strDbPrivileges = 'Privilegije vezane za bazu';
$strDbSpecific = 'Specifino za bazu';
$strDefault = 'Podrazumjevano';
$strDefaultValueHelp = 'Za podrazumjevanu vrijednost, unesite samo jednu vrijednost, bez kosih crta ili navodnika u ovom obliku: a';
$strDelOld = 'Trenutna strana ima reference na tabele koje vie ne postoje. elite li da obriete te reference?';
$strDelete = 'Obrii';
$strDeleteAndFlush = 'Obrii korisnike i ponovo uitaj privilegije.';
$strDeleteAndFlushDescr = 'Ovo je najistiji nain, ali ponovno uitavanje privilegina moe da potraje.';
$strDeleted = 'Red je obrisan';
$strDeletedRows = 'Obrisani redovi:';
$strDeleting = 'Briem %s';
$strDescending = 'Opadajui';
$strDescription = 'Opis';
$strDictionary = 'rijenik';
$strDisabled = 'Onemogueno';
$strDisplayFeat = 'Prikai osobine';
$strDisplayOrder = 'Redosled prikaza:';
$strDisplayPDF = 'Prikai PDF shemu';
$strDoAQuery = 'Napravi "upit po primjeru" (doker: "%")';
$strDoYouReally = 'Da li stvarno hoete da ';
$strDocu = 'Dokumentacija';
$strDrop = 'Odbaci';
$strDropSelectedDatabases = 'Odbaci izabrane baze';
$strDropUsersDb = 'Odbaci baze koje se zovu isto kao korisnici.';
$strDumpSaved = 'Sadraj baze je sauvan u fajl %s.';
$strDumpXRows = 'Prikai %s redova poevi od reda %s.';
$strDumpingData = 'Prikaz podataka tabele';
$strDynamic = 'dinamiki';

$strEdit = 'Promeni';
$strEditPDFPages = 'Izmena PDF strana';
$strEditPrivileges = 'Promijeni privilegije';
$strEffective = 'Efektivne';
$strEmpty = 'Isprazni';
$strEmptyResultSet = 'MySQL je vratio prazan rezultat (nula redova).';
$strEnabled = 'Omogueno';
$strEnd = 'Kraj';
$strEndCut = 'KRAJ REZ';
$strEndRaw = 'KRAJ SIROVO';
$strEnglish = 'Engleski';
$strEnglishPrivileges = ' Napomena: MySQL imena privilegija moraju da budu na engleskom ';
$strError = 'Greka';
$strEstonian = 'Estonski';
$strExcelOptions = 'Excel opcije';
$strExecuteBookmarked = 'Izvri upamen upit';
$strExplain = 'Objasni SQL';
$strExport = 'Izvoz';
$strExtendedInserts = 'Proireni INSERT';
$strExtra = 'Dodatno';

$strFailedAttempts = 'Neuspelih pokuaja';
$strField = 'Polje';
$strFieldHasBeenDropped = 'Polje %s je obrisano';
$strFields = 'Polja';
$strFieldsEmpty = ' Broj polja je nula! ';
$strFieldsEnclosedBy = 'Polja ograniena sa';
$strFieldsEscapedBy = 'Escape karakter &nbsp; &nbsp; &nbsp;';
$strFieldsTerminatedBy = 'Polja razdvojena sa';
$strFileAlreadyExists = 'Datoteka %s ve postoji na serveru, promijenite ime datoteke ili ukljuite opciju prepisivanja.';
$strFileCouldNotBeRead = 'Datoteku nije mogue proitati';
$strFileNameTemplate = 'ablon imena datoteke';
$strFileNameTemplateHelp = 'Koristi __DB__ za ime baze, __TABLE__ za ime tabele  i %sbilo koju strftime%s opciju za specifikaciju vremena, i ekstenzija e automatski biti dodata. Sav ostali tekst bie sauvan.';
$strFileNameTemplateRemember = 'zapamti ablon';
$strFixed = 'uraeno';
$strFlushPrivilegesNote = 'Napomena: phpMyAdmin uzima privilegije korisnika direktno iz MySQL tabela privilegija. Sadraj ove tabele moe se razlikovati od privilegija koje server koristi ako su izvrene rune izmjene. U tom sluaju %sponovo uitajte privilegije%s pre nego to nastavite.';
$strFlushTable = 'Osvjei tabelu ("FLUSH")';
$strFormEmpty = 'Nedostaje vrijednost u obrascu!';
$strFormat = 'Format';
$strFullText = 'Pun tekst';
$strFunction = 'Funkcija';

$strGenBy = 'Generirao';
$strGenTime = 'Vrijeme kreiranja';
$strGeneralRelationFeat = 'Opte osobine relacija';
$strGerman = 'Njemaki';
$strGlobal = 'globalno';
$strGlobalPrivileges = 'Globalne privilegije';
$strGlobalValue = 'Globalna vrednost';
$strGo = 'Kreni';
$strGrantOption = 'Omogui';
$strGreek = 'Grki';
$strGzip = '"gzip-ovano"';

$strHasBeenAltered = 'je promijenjen(a).';
$strHasBeenCreated = 'je kreiran(a).';
$strHaveToShow = 'Morate izabrati bar jednu kolonu za prikaz';
$strHebrew = 'Jevrejski';
$strHome = 'Poetna strana';
$strHomepageOfficial = 'phpMyAdmin veb sajt';
$strHost = 'Host';
$strHostEmpty = 'Ime hosta je prazno!';
$strHungarian = 'Maarski';

$strId = 'ID';
$strIdxFulltext = 'Tekst klju';
$strIfYouWish = 'Ako elite da izlistate samo neke kolone u tabeli, navedite ih razdvojene zarezom';
$strIgnore = 'Ignorii';
$strIgnoringFile = 'Ignoriem fajl %s';
$strImportDocSQL = 'Uvoz docSQL fajlova';
$strImportFiles = 'Uvoz fajlova';
$strImportFinished = 'Uvoz zavren';
$strInUse = 'se koristi';
$strIndex = 'Klju';
$strIndexHasBeenDropped = 'Klju %s je obrisan';
$strIndexName = 'Ime kljua :';
$strIndexType = 'Tip kljua :';
$strIndexes = 'Kljuevi';
$strInnodbStat = 'InnoDB status';
$strInsecureMySQL = 'Va konfiguracioni fajl sadri podeavanja (root bez lozinke) koja odgovaraju standardnom MySQL privilegovanom nalogu. Va MySQL server radi sa ovim podeavanjima, otvoren je za hakovanje, i zaista treba da ispravite ovaj sigurnosni rizik.';
$strInsert = 'Novi zapis';
$strInsertAsNewRow = 'Unesi kao novi red';
$strInsertNewRow = 'Unesi novi red';
$strInsertTextfiles = 'Uvezi podatke iz tekstualne datoteke';
$strInsertedRowId = 'ID umetnutih redova:';
$strInsertedRows = 'Uneseno redova:';
$strInstructions = 'Uputstva';

$strJapanese = 'Japanski';
$strJumpToDB = 'Prei na bazu &quot;%s&quot;.';
$strJustDelete = 'Samo obrii korisnike iz tabele privilegija.';
$strJustDeleteDescr = '&quot;Obrisani&quot; korisnici e i dalje imati pristup serveru dok privilegije ne budu ponovo uitane.';

$strKeepPass = 'Nemoj da mijenja lozinku';
$strKeyname = 'Ime kljua';
$strKill = 'Obustavi';
$strKorean = 'Korejski';

$strLaTeX = 'LaTeX';
$strLaTeXOptions = 'LaTeX opcije';
$strLandscape = 'Poloeno';
$strLengthSet = 'Duina/Vrijednost*';
$strLimitNumRows = 'Broj redova po strani';
$strLineFeed = 'Oznaka za kraj linije: \\n';
$strLinesTerminatedBy = 'Linije se zavravaju sa';
$strLinkNotFound = 'Veza nije pronaena';
$strLinksTo = 'Veze ka';
$strLithuanian = 'Litvanski';
$strLoadExplanation = 'Najbolji metod je ve izabran, ali ga moete promijeniti ako ne radi.';
$strLoadMethod = 'LOAD metod';
$strLocalhost = 'Lokalni';
$strLocationTextfile = 'Lokacija tekstualne datoteke';
$strLogPassword = 'Lozinka:';
$strLogUsername = 'Korisniko ime:';
$strLogin = 'Prijavljivanje';
$strLoginInformation = 'Podatci o prijavi';
$strLogout = 'Odjavljivanje';

$strMIME_MIMEtype = 'MIME-tipovi';
$strMIME_available_mime = 'Dostupni MIME-tipovi';
$strMIME_available_transform = 'Dostupne transformacije';
$strMIME_description = 'Opis';
$strMIME_nodescription = 'Nema opisa za ovu transformaciju.<br />Molimo pitajte autora ta %s radi.';
$strMIME_transformation = 'Tranformacije itaa';
$strMIME_transformation_note = 'Za listu dostupnih opcija transformacije i njihove transformacije MIME-tipova, kliknite na %sopise transformacija%s';
$strMIME_transformation_options = 'Opcije transformacije';
$strMIME_transformation_options_note = 'Molimo unesite vrijednosti za opcije transformacije koristei ovaj oblik: \'a\',\'b\',\'c\'...<br />Ako treba da unesete obrnutu kosu crtu ("\\") ili apostrof ("\'") u te vrijednosti, stavite obrnutu kosu crtu ispred njih (na primjer \'\\\\xyz\' ili \'a\\\'b\').';
$strMIME_without = 'MIME-tipovi prikazani u kursivu nemaju odvojene funkcije transformacije.';
$strModifications = 'Izmjene su sauvane';
$strModify = 'Promijeni';
$strModifyIndexTopic = 'Izmijeni klju';
$strMoreStatusVars = 'Jo statusnih promjenljivih';
$strMoveTable = 'Pomjeri tabelu u (baza<b>.</b>tabela):';
$strMoveTableOK = 'Tabela %s je pomjerena u %s.';
$strMoveTableSameNames = 'Ne mogu da premjestim tabelu u samu sebe!';
$strMultilingual = 'viejeziki';
$strMustSelectFile = 'Morate izabrati datoteku koju elite da umetnete.';
$strMySQLCharset = 'MySQL set karaktera';
$strMySQLReloaded = 'MySQL ponovo pokrenut.';
$strMySQLSaid = 'MySQL kae: ';
$strMySQLServerProcess = 'MySQL %pma_s1% pokrenut na %pma_s2%, prijavljen kao %pma_s3%';
$strMySQLShowProcess = 'Prikai listu procesa';
$strMySQLShowStatus = 'Prikai MySQL informacije o toku rada';
$strMySQLShowVars = 'Prikai MySQL sistemske promenljive';

$strName = 'Ime';
$strNext = 'Slijedei';
$strNo = 'Ne';
$strNoDatabases = 'Baza ne postoji';
$strNoDatabasesSelected = 'Nije izabrana ni jedna baza.';
$strNoDescription = 'nema opisa';
$strNoDropDatabases = '"DROP DATABASE" komanda je onemoguena.';
$strNoExplain = 'Preskoi objanjavanje SQL-a';
$strNoFrames = 'phpMyAdmin preferira itae koji podravaju okvire.';
$strNoIndex = 'Klju nije definisan!';
$strNoIndexPartsDefined = 'Dijelovi kljua nisu definisani!';
$strNoModification = 'Nema izmjena';
$strNoOptions = 'Ne postoje opcije za ovaj format';
$strNoPassword = 'Nema lozinke';
$strNoPermission = 'Veb serveru nije dozvoljeno da sauva datoteku %s.';
$strNoPhp = 'bez PHP koda';
$strNoPrivileges = 'Nema privilegija';
$strNoQuery = 'Nema SQL upita!';
$strNoRights = 'Nije Vam dozvoljeno da budete ovdje!';
$strNoSpace = 'Nedovoljno prostora za snimanje datoteke %s.';
$strNoTablesFound = 'Tabele nisu pronaene u bazi.';
$strNoUsersFound = 'Korisnik nije naen.';
$strNoValidateSQL = 'Preskoi provjeru SQL-a';
$strNone = 'nema';
$strNotNumber = 'Ovo nije broj!';
$strNotOK = 'nije u redu';
$strNotSet = '<b>%s</b> tabela nije pronaena ili nije postavljena u %s';
$strNotValidNumber = 'nije odgovarajui broj kolone!';
$strNull = 'Null';
$strNumSearchResultsInTable = '%s pogodaka unutar tabele <i>%s</i>';
$strNumSearchResultsTotal = '<b>Ukupno:</b> <i>%s</i> pogodaka';
$strNumTables = 'Tabele';

$strOK = 'U redu';
$strOftenQuotation = 'Navodnici koji se koriste. OPCIONO se misli da neka polja mogu, ali ne moraju da budu pod znacima navoda.';
$strOperations = 'Operacije';
$strOptimizeTable = 'Optimiziraj tabelu';
$strOptionalControls = 'Opciono. Znak koji prethodi specijalnim znacima.';
$strOptionally = 'OPCIONO';
$strOr = 'ili';
$strOverhead = 'Prekoraenje';
$strOverwriteExisting = 'Prepii postojee fajlove';

$strPHP40203 = 'Koristite PHP 4.2.3, koji ima ozbiljnu gresku sa viebajtnim stringovima (mbstring). Pogledajte izvjetaj o greci br. 19404. Ova verzija PHP-a se ne preporuuje za korienje sa phpMyAdmin.';
$strPHPVersion = 'verzija PHP-a';
$strPageNumber = 'Broj strane:';
$strPaperSize = 'Dimenzije papira';
$strPartialText = 'Dio teksta';
$strPassword = 'Lozinka';
$strPasswordChanged = 'Lozinka za %s je uspjeno promjenjena.';
$strPasswordEmpty = 'Lozinka je prazna!';
$strPasswordNotSame = 'Lozinke nisu identine!';
$strPdfDbSchema = 'Shema baze "%s" - Strana %s';
$strPdfInvalidTblName = 'Tabela "%s" ne postoji!';
$strPdfNoTables = 'Nema tabela';
$strPerHour = 'na sat';
$strPerMinute = 'u minuti';
$strPerSecond = 'u sekundi';
$strPhoneBook = 'telefonski imenik';
$strPhp = 'Napravi PHP kod';
$strPmaDocumentation = 'phpMyAdmin dokumentacija';
$strPmaUriError = '<tt>$cfg[\'PmaAbsoluteUri\']</tt> direktiva MORA biti podjeena u konfiguracionoj datoteci!';
$strPortrait = 'Uspravno';
$strPos1 = 'Poetak';
$strPrevious = 'Prethodna';
$strPrimary = 'Primarni';
$strPrimaryKeyHasBeenDropped = 'Primarni klju je obrisan';
$strPrimaryKeyName = 'Ime primarnog kljua mora da bude... PRIMARY!';
$strPrimaryKeyWarning = '("PRIMARY" <b>mora</b> biti ime <b>samo</b> primarnog kljua!)';
$strPrint = 'tampaj';
$strPrintView = 'Za tampu';
$strPrivDescAllPrivileges = 'Ukljuuje sve privilegije osim GRANT.';
$strPrivDescAlter = 'Dozvoljava izmjenu struktura postojeih tabela.';
$strPrivDescCreateDb = 'Dozvoljava kreiranje novih baza i tabela.';
$strPrivDescCreateTbl = 'Dozvoljava kreiranje novih tabela.';
$strPrivDescCreateTmpTable = 'Dozvoljava kreiranje privremenih tabela..';
$strPrivDescDelete = 'Dozvoljava brisanje podataka.';
$strPrivDescDropDb = 'Dozvoljava odbacivanje baza i tabela.';
$strPrivDescDropTbl = 'Dozvoljava odbacivanje tabela.';
$strPrivDescExecute = 'Dozvoljava pokretanje sauvanih procedura. Nema efekta u ovoj verziji MySQL-a.';
$strPrivDescFile = 'Dozvoljava uvoz podataka i njihov izvoz u datoteke.';
$strPrivDescGrant = 'Dozvoljava dodavanje korisnika i privilegija bez ponovnog uitavanja tabela privilegija.';
$strPrivDescIndex = 'Dozvoljava kreiranje i brisanje kljueva.';
$strPrivDescInsert = 'Dozvoljava umetanje i zamjenu podataka.';
$strPrivDescLockTables = 'Dozvoljava zakljuavanje tabela tekuim procesima.';
$strPrivDescMaxConnections = 'Ograniava broj novih konekcija koje korisnik moe ta otvori na sat.';
$strPrivDescMaxQuestions = 'Ograniava broj upita koje korisnik moe da uputi serveru za sat.';
$strPrivDescMaxUpdates = 'Ograniava broj komandi koje menjaju tabele ili baze koje korisnik moe da izvri na sat.';
$strPrivDescProcess3 = 'Dozvoljava prekidanje procesa drugih korisnika.';
$strPrivDescProcess4 = 'Dozvoljava pregled kompletnih upita u listi procesa.';
$strPrivDescReferences = 'Nema efekta u ovoj verziji MySQL-a.';
$strPrivDescReload = 'Dozvoljava ponovno uitavanje podeavanja servera i pranjenje kea servera.';
$strPrivDescReplClient = 'Daje pravo korisniku da pita gde su glavni/pomoni serveri.';
$strPrivDescReplSlave = 'Potrebno zbog pomonih servera za replikaciju.';
$strPrivDescSelect = 'Dozvoljava itanje podataka.';
$strPrivDescShowDb = 'Daje pristup kompletnoj listi baza.';
$strPrivDescShutdown = 'Dozvoljava gaenje servera.';
$strPrivDescSuper = ' Dozvoljava povezivanje iako je dostignut maksimalan broj dozvoljenih veza; Neophodno za veinu administrativnih opcija kao to su podeavanje globalnih promenljivih ili prekidanje procesa ostalih korisnika.';
$strPrivDescUpdate = 'Dozvoljava izmenu podataka.';
$strPrivDescUsage = 'Nema privilegija.';
$strPrivileges = 'Privilegije';
$strPrivilegesReloaded = 'Privilegije su uspeno ponovo uitane.';
$strProcesslist = 'Lista procesa';
$strPutColNames = 'Stavi imena polja u prvi red';

$strQBE = 'Upit po primeru';
$strQBEDel = 'Del';
$strQBEIns = 'Ins';
$strQueryFrame = 'Prozor za upite';
$strQueryOnDb = 'SQL upit na bazi <b>%s</b>:';
$strQuerySQLHistory = 'SQL istorijat';
$strQueryStatistics = '<b>Statistike upita</b>: %s upita je postavljeno serveru od njegovog pokretanja.';
$strQueryTime = 'Upit je trajao %01.4f sekundi';
$strQueryType = 'Vrsta upita';
$strQueryWindowLock = 'Ne prepisuj ovaj upit izvan prozora';

$strReType = 'Ponovite unos';
$strReceived = 'Primljeno';
$strRecords = 'Zapisi';
$strReferentialIntegrity = 'Proveri referencijalni integritet:';
$strRelationNotWorking = 'Dodatne mogunosti za rad sa povezanim tabelama su iskljuene. Da biste saznali zato, kliknite %sovde%s.';
$strRelationView = 'Relacioni pogled';
$strRelationalSchema = 'Relaciona shema';
$strRelations = 'Relacije';
$strReloadFailed = 'Ponovno pokretanje MySQL-a nije uspelo.';
$strReloadMySQL = 'Ponovo pokreni MySQL';
$strReloadingThePrivileges = 'Ponovo uitavam privilegije';
$strRemoveSelectedUsers = 'Ukloni izabrane korisnike';
$strRenameTable = 'Promjeni ime tabele u ';
$strRenameTableOK = 'Tabeli %s promjenjeno ime u %s';
$strRepairTable = 'Popravi tabelu';
$strReplace = 'Zamijeni';
$strReplaceNULLBy = 'Zamijeni NULL sa';
$strReplaceTable = 'Zamijeni podatke u tabeli sa podatcima iz datoteke';
$strReset = 'Resetuj';
$strResourceLimits = 'Ogranienja resursa';
$strRevoke = 'Zabrani';
$strRevokeAndDelete = 'Obustavi sve aktivne privilegije korisnika i zatim ih obrii.';
$strRevokeAndDeleteDescr = 'Korisnici e i dalje imati USAGE privilegije dok se privilegije ponovo ne uitaju.';
$strRevokeMessage = 'Zabranili ste privilegije za %s';
$strRowLength = 'Duina reda';
$strRowSize = 'Veliina reda';
$strRows = 'Redova';
$strRowsFrom = ' redova poev od reda';
$strRowsModeFlippedHorizontal = 'horizontalnom (rotirana zaglavlja)';
$strRowsModeHorizontal = 'horizontalnom';
$strRowsModeOptions = 'u %s modu i ponovi zaglavlje posle svakog %s reda';
$strRowsModeVertical = 'vertikalnom';
$strRowsStatistic = 'Statistike reda';
$strRunQuery = 'Izvri SQL upit';
$strRunSQLQuery = 'Izvri SQL upit(e) na bazi %s';
$strRunning = 'na serveru %s';
$strRussian = 'Ruski';

$strSQL = 'SQL';
$strSQLOptions = 'SQL opcije';
$strSQLParserBugMessage = 'Postoji mogunost da ste pronali gresku u SQL parseru. Molimo ispitajte svoj upit paljivo, i provjerite da su navodnici ispravni i da ne nedostaju. Ostali mogui razlozi greke mogu biti da ste poslali binarni fajl van oblasti za obian tekst. Moete probati svoj upit u MySQL interfejsu komandne linije. Donja poruka o greci MySQL servera, ako je ima, moe vam pomoi u otkrivanju problema. Ako i dalje imate probleme ili ako parser ne uspjeva tamo gde uspeva interfejs komandne linije, svedite svoj SQL upit na jedan jedini upit koji stvara probleme i poaljite nam izvjetaj o greci sa delom koda u donjoj REZ sekciji:';
$strSQLParserUserError = 'Izgleda da postoji greka u vaem SQL upitu. Ovde je poruka o greki MySQL servera, koja vam moe pomoi u otkrivanju problema';
$strSQLQuery = 'SQL upit';
$strSQLResult = 'SQL rezultat';
$strSQPBugInvalidIdentifer = 'Neispravan identifikator';
$strSQPBugUnclosedQuote = 'Navodnik nije zatvoren';
$strSQPBugUnknownPunctuation = 'Nepoznat string interpunkcije';
$strSave = 'Sauvaj';
$strSaveOnServer = 'Sauvaj na server u direktorijum %s';
$strScaleFactorSmall = 'Faktor umanjenja je premali da bi shema stala na jednu stranu';
$strSearch = 'Pretraivanje';
$strSearchFormTitle = 'Pretraivanje baze';
$strSearchInTables = 'Unutar tabela:';
$strSearchNeedle = 'Rijei ili vrednosti koje se trae (doker: "%"):';
$strSearchOption1 = 'bar jednu od rijei';
$strSearchOption2 = 'sve rijei';
$strSearchOption3 = 'taan izraz';
$strSearchOption4 = 'kao regularni izraz';
$strSearchResultsFor = 'Rezultati pretrage za "<i>%s</i>" %s:';
$strSearchType = 'Trai:';
$strSecretRequired = 'Konfiguraciona datoteka zahtjeva tajnu lozinku (blowfish_secret).';
$strSelectADb = 'Izaberite bazu';
$strSelectAll = 'Izaberi sve';
$strSelectFields = 'Izaberi polja (najmanje jedno)';
$strSelectNumRows = 'u upitu';
$strSelectTables = 'Izaberi tabele';
$strSend = 'Sauvaj kao datoteku';
$strSent = 'Poslato';
$strServer = 'Server';
$strServerChoice = 'Izbor servera';
$strServerStatus = 'Informacije o toku rada';
$strServerStatusUptime = 'Ovaj MySQL server radi ve %s. Pokrenut je %s.';
$strServerTabProcesslist = 'Procesi';
$strServerTabVariables = 'Promjenljive';
$strServerTrafficNotes = '<b>Saobraaj servera</b>: Tabele pokazuju statistike mrenog saobraaja na ovom MySQL serveru od njegovog pokretanja.';
$strServerVars = 'Serverske promenljive i podeavanja';
$strServerVersion = 'Verzija servera';
$strSessionValue = 'Vrijednost sesije';
$strSetEnumVal = 'Ako je polje "enum" ili "set", unesite vrijednosti u formatu: \'a\',\'b\',\'c\'...<br />Ako vam treba obrnuta kosa crta ("\\") ili apostrof ("\'") koristite ih u "izbjegnutom" (escaped) obliku (na primer \'\\\\xyz\' ili \'a\\\'b\').';
$strShow = 'Prikai';
$strShowAll = 'Prikai sve';
$strShowColor = 'Prikai boju';
$strShowDatadictAs = 'Format rijenika podataka';
$strShowFullQueries = 'Prikai kompletne upite';
$strShowGrid = 'Prikai mreu';
$strShowPHPInfo = 'Prikai informacije o PHP-u';
$strShowTableDimension = 'Prikai dimenzije tabele';
$strShowTables = 'Prikai tabele';
$strShowThisQuery = 'Prikai ponovo ovaj upit';
$strShowingRecords = 'Prikaz zapisa';
$strSimplifiedChinese = 'Pojednostavljeni kineski';
$strSingly = '(po jednom polju)';
$strSize = 'Veliina';
$strSort = 'Sortiranje';
$strSpaceUsage = 'Zauzee';
$strSplitWordsWithSpace = 'Rijei se odvajaju razmakom (" ").';
$strStatCheckTime = 'Posljednja provjera';
$strStatCreateTime = 'Napravljeno';
$strStatUpdateTime = 'Posljednja izmjena';
$strStatement = 'Ime';
$strStatus = 'Status';
$strStrucCSV = 'CSV format';
$strStrucData = 'Struktura i podatci';
$strStrucDrop = 'Dodaj \'DROP TABLE\'';
$strStrucExcelCSV = 'CSV za MS Excel';
$strStrucOnly = 'Samo struktura';
$strStructPropose = 'Predloi strukturu tabele';
$strStructure = 'Struktura';
$strSubmit = 'Poalji';
$strSuccess = 'Va SQL upit je uspeno izvren';
$strSum = 'Ukupno';
$strSwedish = 'vedski';
$strSwitchToTable = 'Prei na kopiranu tabelu';

$strTable = 'Tabela';
$strTableComments = 'Komentari tabele';
$strTableEmpty = 'Ima tabele je prazno!';
$strTableHasBeenDropped = 'Tabela %s je odbaena';
$strTableHasBeenEmptied = 'Tabela %s je ispranjena';
$strTableHasBeenFlushed = 'Tabela %s je osveena';
$strTableMaintenance = 'Radnje na tabeli';
$strTableOfContents = 'Sadraj';
$strTableOptions = 'Opcije tabele';
$strTableStructure = 'Struktura tabele';
$strTableType = 'Tip tabele';
$strTables = '%s tabela';
$strTblPrivileges = 'Privilegije vezane za tabele';
$strTextAreaLength = 'Zbog njehove veliine, polje<br />moda neete moi da izmenite';
$strThai = 'Tajlandski ';
$strTheContent = 'Sadraj datoteke je dodat u bazu.';
$strTheContents = 'Podatke sadrane u tabeli zameni sa podacima iz datoteke koji imaju identine primarne i jedinstvene (unique) kljueve.';
$strTheTerminator = 'Separator polja u datoteci.';
$strThisHost = 'Ovaj server';
$strThisNotDirectory = 'Ovo nije direktorijum';
$strThreadSuccessfullyKilled = 'Proces %s je uspjeno prekinut.';
$strTime = 'Vrijeme';
$strToggleScratchboard = 'Ukljuuje/iskljuuje scratchboard';
$strTotal = 'ukupno';
$strTotalUC = 'Ukupno';
$strTraditionalChinese = 'Tradicionalni kineski';
$strTraffic = 'Saobraaj';
$strTransformation_image_jpeg__inline = 'Prikazuje umanjenu sliku na koju je mogue kliknuti; opcije: irina, visina u pikselima (uva originalni odnos)';
$strTransformation_image_jpeg__link = 'Prikazuje link ka ovoj slici (npr. direktno preuzimanje iz BLOB-a).';
$strTransformation_image_png__inline = 'Prikai JPEG slike na strani';
$strTransformation_text_plain__dateformat = 'Uzima TIME, TIMESTAMP ili DATETIME polje i formatira ga koristei lokalni oblik prikazivanja datuma. Prva opcija je ofset (u satima) koji se dodaje vremenskoj oznaci (podrazumevano: 0). Druga opcija je razliit format datuma prema parametrima koji su dostupni za PHP-ov strftime().';
$strTransformation_text_plain__external = 'SAMO LINUX: Pokree eksternu aplikaciju i popunjava podatke u poljima preko standardnog ulaza. Vraa standardni izlaz aplikacije. Podrazumevano je Tidy, za lepi prikaz HTML koda. Zbog sigurnosnih razloga, morate runo izmeniti datoteku libraries/transformations/text_plain__external.inc.php i dodati alate koje elite da koristite. Prva opcija je broj programa koje elite da koristite, a druga su parametri programa. Ako se trei parametar postavi na 1 izlaz e biti konvertovan koristei htmlspecialchars() (podrazumevano je 1). Ako je etvrti parametar postavljen na 1, NOWRAP e biti dodato eliji sa sadrajem tako da e izlaz biti prikazan bez izmena. (podrazumevano 1)';
$strTransformation_text_plain__formatted = 'uva originalno formatiranje polja. Escaping se ne vri.';
$strTransformation_text_plain__imagelink = 'Prikazuje sliku i link, polje sadri naziv datoteke; prva opcija je prefiks kao "http://domain.com/", druga opcija je irina u pikselima, trea je visina.';
$strTransformation_text_plain__link = 'Prikazuje link, polje sadri naziv datoteke; prva opcija je prefiks kao "http://domain.com/", druga opcija je naslov za link.';
$strTransformation_text_plain__substr = 'Pokazuje samo deo stringa. Prva opcija je ofset koji definie gde poinje izlaz vaeg teksta (podrazumevano 0). Druga opcija je ofset koji pokazuje koliko e teksta biti prikazano. Ako je nema, sav preostali tekst e biti prikazan. Trea opcija odreuje koji e znaci biti dodati izlazu kada se prikae podstring (podrazumevano: ...) .';
$strTruncateQueries = 'Prikai skraene upite';
$strTurkish = 'Turski';
$strType = 'Tip';

$strUkrainian = 'Ukrajinski';
$strUncheckAll = 'nijedno';
$strUnicode = 'Unikod';
$strUnique = 'Jedinstveni';
$strUnknown = 'nepoznat';
$strUnselectAll = 'nita';
$strUpdComTab = 'Molimo pogledajte u dokumentaciji kako se aurira tabela Column_comments';
$strUpdatePrivMessage = 'Aurirali ste privilegije za %s.';
$strUpdateProfileMessage = 'Profil je promjenjen.';
$strUpdateQuery = 'Auriraj upit';
$strUsage = 'Zauzee';
$strUseBackquotes = 'Koristi \' za ograniavanje imena polja';
$strUseHostTable = 'Koristi tabelu hosta';
$strUseTables = 'Koristi tabele';
$strUseTextField = 'Koristi tekst polje';
$strUseThisValue = 'Koristi ovu vrijednost';
$strUser = 'Korisnik';
$strUserAlreadyExists = 'Korisnik %s ve postoji!';
$strUserEmpty = 'Ime korisnika nije unijeto!';
$strUserName = 'Ime korisnika';
$strUserNotFound = 'Izabrani korisnik nije pronaen u tabeli privilegija.';
$strUserOverview = 'Pregled korisnika';
$strUsersDeleted = 'Izabrani korisnici su uspjeno obrisani.';
$strUsersHavingAccessToDb = 'Korisnici koji imaju pristup &quot;%s&quot;';

$strValidateSQL = 'Provjeri SQL';
$strValidatorError = 'SQL validator nije mogao da bude pokrenut. Proverite da li su instalirane neophodne PHP ekstenzije opisane u  %sdokumentaciji%s.';
$strValue = 'Vrijednost';
$strVar = 'Promjenljiva';
$strViewDump = 'Prikai sadraj (shemu) tabele';
$strViewDumpDB = 'Prikai sadraj (shemu) baze';
$strViewDumpDatabases = 'Prikai sadraj (shemu) baze';

$strWebServerUploadDirectory = 'direkcija za slanje web servera ';
$strWebServerUploadDirectoryError = 'Direkcija koju ste izabrali za slanje nije dostupna';
$strWelcome = 'Dobrodoli na %s';
$strWestEuropean = 'Zapadnoevropski';
$strWildcard = 'Doker';
$strWindowNotFound = 'Odredinji prozor pretraivaa nije mogao da bude auriran. Moda ste zatvorili matini prozor, ili va preraiva onemoguava auriranje meu prozorima zbog sigurnosnih podeavanja';
$strWithChecked = 'Oznaeno:';
$strWritingCommentNotPossible = 'Pisanje komentara nije mogue';
$strWritingRelationNotPossible = 'Upisivanje relacije nije mogue';
$strWrongUser = 'Pogreno korisniko ime/lozinka. Ulaz nije dozvoljen.';

$strXML = 'XML';

$strYes = 'Da';

$strZeroRemovesTheLimit = 'Napomena: Postavljanje ovih opcija na 0 (nulu) uklanja limite.';
$strZip = '"zipovano"';

$strBookmarkAllUsers = 'Let every user access this bookmark';  //to translate
$strBookmarkOptions = 'Bookmark options';  //to translate

$strCheckOverhead = 'Check tables with overhead';  //to translate
$strConstraintsForDumped = 'Constraints for dumped tables';  //to translate
$strConstraintsForTable = 'Constraints for table';  //to translate
$strCreationDates = 'Creation/Update/Check dates';  //to translate

$strInternalNotNecessary = '* An internal relation is not necessary when it exists also in InnoDB.';  //to translate
$strInternalRelations = 'Internal relations';  //to translate

$strLatexCaption = 'Table caption';  //to translate
$strLatexContent = 'Content of table __TABLE__';  //to translate
$strLatexContinued = '(continued)';  //to translate
$strLatexContinuedCaption = 'Continued table caption';  //to translate
$strLatexIncludeCaption = 'Include table caption';  //to translate
$strLatexLabel = 'Label key';  //to translate
$strLatexStructure = 'Structure of table __TABLE__';  //to translate
$strLogServer = 'Server';  //to translate

$strPrintViewFull = 'Print view (with full texts)';  //to translate

$strSortByKey = 'Sort by key';  //to translate

$strUpgrade = 'You should upgrade to %s %s or later.';  //to translate

$strExcelEdition = 'Excel edition';  //to translate
$strDelayedInserts = 'Use delayed inserts';  //to translate
$strSQLExportType = 'Export type';  //to translate
$strAddConstraints = 'Add constraints';  //to translate
$strGeorgian = 'Georgian';  //to translate
$strCzechSlovak = 'Czech-Slovak';  //to translate
$strTransformation_application_octetstream__download = 'Display a link to download the binary data of a field. First option is the filename of the binary file. Second option is a possible fieldname of a table row containing the filename. If you provide a second option you need to have the first option set to an empty string';  //to translate
$strMaximumSize = 'Maximum size: %s%s';  //to translate
$strConnectionError = 'Cannot connect: invalid settings.';  //to translate
$strDropDatabaseStrongWarning = 'You are about to DESTROY a complete database!';  //to translate
$strAddHeaderComment = 'Add custom comment into header (\\n splits lines)';  //to translate
$strNeedPrimaryKey = 'You should define a primary key for this table.';  //to translate
$strIgnoreInserts = 'Use ignore inserts';  //to translate
$strAddIfNotExists = 'Add IF NOT EXISTS';  //to translate
$strCommentsForTable = 'COMMENTS FOR TABLE';  //to translate
$strMIMETypesForTable = 'MIME TYPES FOR TABLE';  //to translate
$strRelationsForTable = 'RELATIONS FOR TABLE';  //to translate
$strAfterInsertSame = 'Go back to this page';  //to translate
$strRenameDatabaseOK = 'Database %s has been renamed to %s';  //to translate
$strDatabaseEmpty = 'The database name is empty!';  //to translate
$strDBRename = 'Rename database to';  //to translate
$strOperator = 'Operator';  //to translate
$strEncloseInTransaction = 'Enclose export in a transaction';  //to translate
$strCalendar = 'Calendar';  //to translate
$strRefresh = 'Refresh';  //to translate
$strDefragment = 'Defragment table';  //to translate
$strNoRowsSelected = 'No rows selected';  //to translate
$strSpanish = 'Spanish';  //to translate
$strStrucNativeExcel = 'Native MS Excel data';  //to translate
$strDisableForeignChecks = 'Disable foreign key checks';  //to translate
$strServerNotResponding = 'The server is not responding';  //to translate
$strTheme = 'Theme / Style';  //to translate
$strTakeIt = 'take it';  //to translate
$strHexForBinary = 'Use hexadecimal for binary fields';  //to translate
$strIcelandic = 'Icelandic';  //to translate
$strLatvian = 'Latvian';  //to translate
$strPolish = 'Polish';  //to translate
$strRomanian = 'Romanian';  //to translate
$strSlovenian = 'Slovenian';  //to translate
$strTraditionalSpanish = 'Traditional Spanish';  //to translate
$strSlovak = 'Slovak';  //to translate
$strMySQLConnectionCollation = 'MySQL connection collation';  //to translate
$strPersian = 'Persian';  //to translate
$strAddFields = 'Add %s field(s)';  //to translate
$strInsertBookmarkTitle = 'Please insert bookmark title';  //to translate
$strNoThemeSupport = 'No themes support, please check your configuration and/or your themes in directory %s.';  //to translate
$strUseTabKey = 'Use TAB key to move from value to value, or CTRL+arrows to move anywhere';  //to translate
$strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them literally';  //to translate
$strBinLogName = 'Log name';  //to translate
$strBinLogPosition = 'Position';  //to translate
$strBinLogEventType = 'Event type';  //to translate
$strBinLogServerId = 'Server ID';  //to translate
$strBinLogOriginalPosition = 'Original position';  //to translate
$strBinLogInfo = 'Information';  //to translate
$strBinaryLog = 'Binary log';  //to translate
$strSelectBinaryLog = 'Select binary log to view';  //to translate
$strDBCopy = 'Copy database to';  //to translate
$strCopyDatabaseOK = 'Database %s has been copied to %s';  //to translate
$strSwitchToDatabase = 'Switch to copied database';  //to translate
$strPasswordHashing = 'Password Hashing';  //to translate
$strCompatibleHashing = 'MySQL&nbsp;4.0 compatible';  //to translate
$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
$strIndexWarningTable = 'Problems with indexes of table `%s`';//to translate
$strNoActivity = 'No activity since %s seconds or more, please login again';  //to translate
$strApproximateCount = 'May be approximate. See FAQ 3.11';  //to translate
$strSQLExportCompatibility = 'SQL export compatibility';  //to translate
$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
$strAfterInsertNext = 'Edit next row';  //to translate
$strView = 'View';  //to translate
$strViewHasBeenDropped = 'View %s has been dropped';  //to translate
$strEngines = 'Engines';  //to translate
$strStorageEngines = 'Storage Engines';  //to translate
$strStorageEngine = 'Storage Engine';  //to translate
$strNoDetailsForEngine = 'There is no detailed status information available for this storage engine.';  //to translate
$strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
$strEngineAvailable = '%s is available on this MySQL server.';  //to translate
$strEngineUnsupported = 'This MySQL server does not support the %s storage engine.';  //to translate
$strEngineDisabled = '%s has been disabled for this MySQL server.';  //to translate
$strMyISAMSortBufferSize = 'Sort buffer size';  //to translate
$strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate
$strMyISAMDataPointerSize = 'Data pointer size';  //to translate
$strMyISAMDataPointerSizeDesc = 'The default pointer size in bytes, to be used by CREATE TABLE for MyISAM tables when no MAX_ROWS option is specified.';  //to translate
$strMyISAMRecoverOptions = 'Automatic recovery mode';  //to translate
$strMyISAMRecoverOptionsDesc = 'The mode for automatic recovery of crashed MyISAM tables, as set via the --myisam-recover server startup option.';  //to translate
$strMyISAMRepairThreads = 'Repair threads';  //to translate
$strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table indexes are created in parallel (each index in its own thread) during the Repair by sorting process.';  //to translate
$strMyISAMMaxSortFileSize = 'Maximum size for temporary sort files';  //to translate
$strMyISAMMaxSortFileSizeDesc = 'The maximum size of the temporary file MySQL is allowed to use while re-creating a MyISAM index (during REPAIR TABLE, ALTER TABLE, or LOAD DATA INFILE).';  //to translate
$strMyISAMMaxExtraSortFileSize = 'Maximum size for temporary files on index creation';  //to translate
$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
$strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
$strVersionInformation = 'Version information';  //to translate
$strInnoDBDataHomeDir = 'Data home directory';  //to translate
$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
$strInnoDBDataFilePath = 'Data files';  //to translate
$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
$strBufferPool = 'Buffer Pool';  //to translate
$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
$strDataPages = 'Pages containing data';  //to translate
$strFreePages = 'Free pages';  //to translate
$strBusyPages = 'Busy pages';  //to translate
$strDirtyPages = 'Dirty pages';  //to translate
$strPagesToBeFlushed = 'Pages to be flushed';  //to translate
$strLatchedPages = 'Latched pages';  //to translate
$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
$strReadRequests = 'Read requests';  //to translate
$strWriteRequests = 'Write requests';  //to translate
$strBufferReadMisses = 'Read misses';  //to translate
$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
$strBufferWriteWaits = 'Write waits';  //to translate
$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
$strHTMLExcel = 'Microsoft Excel 2000';  //to translate
$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
$strHTMLWord = 'Microsoft Word 2000';  //to translate
$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
$strInnoDBPages = 'pages';  //to translate
$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
$strPrivDescCreateView = 'Allows creating new views.';  //to translate
$strPrivDescAlterDb = 'Allows altering the structure of existing tables as well as changing the default charset and collation of databases.';  //to translate
$strPrivDescCreateUser = 'Allows creating, dropping and renaming unser accounts.';  //to translate
$strPrivDescCreateRoutine = 'Allows creating stored routines.';  //to translate
$strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
$strRoutines = 'Routines';  //to translate
$strPrivDescShowView = 'Allows performing SHOW CREATE VIEW queries.';  //to translate
$strPrivDescExecute5 = 'Allows executing stored routines.';  //to translate
$strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
$strGeneratePassword = 'Generate Password';  //to translate
$strGenerate = 'Generate';  //to translate
$strCopy = 'Copy';  //to translate
?>
